uniform mat4 u_MVPMatrix;		// A constant representing the combined model/view/projection matrix.
uniform mat4 u_MVMatrix;		// A constant representing the combined model/view matrix.
uniform float u_Time;
uniform float u_Speed;
uniform vec2 u_Resolution;

attribute vec4 a_Position; //initial
attribute vec2 a_TexCoordinate;
attribute vec4 a_Misc; //initial

varying vec2 v_TexCoordinate;
varying float v_Radius;

#define RADIUS 2.0

void main()
{
	// Pass through the texture coordinate.
	v_TexCoordinate = a_TexCoordinate;

	vec2 centerPos = a_Position.xy;

	float f = mix(1.0, a_Misc.t * u_Speed, u_Time);

    centerPos *= mod(f, RADIUS);

    float size = a_Misc.s;

    size = mix(0.01, size, mod(f, RADIUS) / RADIUS);

    vec2 relativePos = vec2(
	  (a_TexCoordinate.s - 0.5) * 2.0 * size,
	  (a_TexCoordinate.t - 0.5) * 2.0 * size
    );

	vec4 pos = vec4(
	relativePos + centerPos,
	  0.0,
	  1.0
	);

	gl_Position = u_MVPMatrix * pos;
	v_Radius = size * 2.0;
}
